Continued a bit:
[mailer.git] / js.php
diff --git a/js.php b/js.php
index 2b27f51aa9f5ff1973f104f06004edafb112a141..49e7946740f20040ab099fd41d7a9a20b9077cee 100644 (file)
--- a/js.php
+++ b/js.php
  * -------------------------------------------------------------------- *
  * Kurzbeschreibung  : Code-Bild fuer verschiedene Zwecke               *
  * -------------------------------------------------------------------- *
- * $Revision::                                                        $ *
- * $Date::                                                            $ *
- * $Tag:: 0.2.1-FINAL                                                 $ *
- * $Author::                                                          $ *
- * -------------------------------------------------------------------- *
  * Copyright (c) 2003 - 2009 by Roland Haeder                           *
- * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
 // Load security stuff here
 require('inc/libs/security_functions.php');
 
-// This is a fake-CSS file loader, more a JavaScript loader...
-// This is in one way good and in one not. The whole reset part will be
-// by-passed even in this "faked" CSS mode. The bad news is that this makes all
-// JS calls on this script to CSS calls. So no real "request" like in MVC
-// pattern is given...
-//
-// But mxchange 0.3.0 will show that in better way! :D :D :D
-$GLOBALS['output_mode'] = 1;
-$GLOBALS['module'] = 'js';
+// Init start time
+$GLOBALS['__start_time'] = microtime(TRUE);
+
+/*
+ * This is a fake-CSS file loader, more a JavaScript loader...
+ * This is in one way good and in one not. The whole reset part will be
+ * by-passed even in this "faked" CSS mode. The bad news is that this makes all
+ * JS calls on this script to CSS calls. So no real "request" like in MVC
+ * pattern is given...
+ *
+ * But Mailer-Project 0.3.0 will show that in better way! :D :D :D
+ */
+$GLOBALS['__module']      = 'js';
+$GLOBALS['__output_mode'] = 1;
 
 // Load the required file(s)
 require('inc/config-global.php');
 
 // Set header and HTTP status
 setContentType('text/javascript');
-setHttpStatus('404 NOT FOUND');
+setHttpStatus('404 Not Found');
 
 // Is 'js' is provied?
-if (isGetRequestParameterSet('js')) {
+if (isGetRequestElementSet('js')) {
        // Load header
-       loadIncludeOnce('inc/header.php');
+       loadPageHeader();
 
        // Prepare include file for looking
-       $inc = sprintf("inc/js/js-%s.php",
-               getRequestParameter('js')
-       );
+       $inc = sprintf('inc/js/js-%s.php', getRequestElement('js'));
 
        // Is that file readable?
        if (isIncludeReadable($inc)) {
@@ -78,11 +76,11 @@ if (isGetRequestParameterSet('js')) {
        } // END - if
 
        // Load footer
-       loadIncludeOnce('inc/footer.php');
+       loadPageFooter();
 } // END - if
 
 // Shutdown
-shutdown();
+doShutdown();
 
 // [EOF]
 ?>